# 📜 bluer_flow

📜 `bluer_flow` for workflow management.

```bash
pip install bluer_flow
```

|   |   |   |   |   |
| --- | --- | --- | --- | --- |
| 📜 | [`a-bc-d`](./patterns/a-bc-d.dot) | [`hourglass`](./patterns/hourglass.dot) | [`map-reduce`](./patterns/map-reduce.dot) | [`map-reduce-large`](./patterns/map-reduce-large.dot) |
| [generic](./runners/generic.py) | [![image](ToDo: use assets/generic-a-bc-d/workflow.gif?raw=true&random=6uyo90v1j0iey6po)](ToDo: use assets/generic-a-bc-d/workflow.gif?raw=true&random=6uyo90v1j0iey6po) [🔗](ToDo: use assets/generic-a-bc-d/workflow.gif?raw=true&random=6uyo90v1j0iey6po) | [![image](ToDo: use assets/generic-hourglass/workflow.gif?raw=true&random=5lo80seuueciecbd)](ToDo: use assets/generic-hourglass/workflow.gif?raw=true&random=5lo80seuueciecbd) [🔗](ToDo: use assets/generic-hourglass/workflow.gif?raw=true&random=5lo80seuueciecbd) | [![image](ToDo: use assets/generic-map-reduce/workflow.gif?raw=true&random=s29zwlyzfxvdn8g4)](ToDo: use assets/generic-map-reduce/workflow.gif?raw=true&random=s29zwlyzfxvdn8g4) [🔗](ToDo: use assets/generic-map-reduce/workflow.gif?raw=true&random=s29zwlyzfxvdn8g4) | [![image](ToDo: use assets/generic-map-reduce-large/workflow.gif?raw=true&random=0be6e55sfnyyrvjz)](ToDo: use assets/generic-map-reduce-large/workflow.gif?raw=true&random=0be6e55sfnyyrvjz) [🔗](ToDo: use assets/generic-map-reduce-large/workflow.gif?raw=true&random=0be6e55sfnyyrvjz) |
| [local](./runners/local.py) | [![image](ToDo: use assets/local-a-bc-d/workflow.gif?raw=true&random=sxecpyq5aznsyc59)](ToDo: use assets/local-a-bc-d/workflow.gif?raw=true&random=sxecpyq5aznsyc59) [🔗](ToDo: use assets/local-a-bc-d/workflow.gif?raw=true&random=sxecpyq5aznsyc59) | [![image](ToDo: use assets/local-hourglass/workflow.gif?raw=true&random=rm4la1fagphc6nv5)](ToDo: use assets/local-hourglass/workflow.gif?raw=true&random=rm4la1fagphc6nv5) [🔗](ToDo: use assets/local-hourglass/workflow.gif?raw=true&random=rm4la1fagphc6nv5) | [![image](ToDo: use assets/local-map-reduce/workflow.gif?raw=true&random=331biby9g5spz3zv)](ToDo: use assets/local-map-reduce/workflow.gif?raw=true&random=331biby9g5spz3zv) [🔗](ToDo: use assets/local-map-reduce/workflow.gif?raw=true&random=331biby9g5spz3zv) | [![image](ToDo: use assets/local-map-reduce-large/workflow.gif?raw=true&random=jy2qiuhivz8mzrr4)](ToDo: use assets/local-map-reduce-large/workflow.gif?raw=true&random=jy2qiuhivz8mzrr4) [🔗](ToDo: use assets/local-map-reduce-large/workflow.gif?raw=true&random=jy2qiuhivz8mzrr4) |

💡 example use: [literature review using OpenAI API](https://github.com/kamangir/openai-commands/tree/main/openai_commands/literature_review).

---

> 🌀 [`blueflow`](https://github.com/kamangir/notebooks-and-scripts) for the [Global South](https://github.com/kamangir/bluer-south).

---


[![pylint](https://github.com/kamangir/bluer-flow/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-flow/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-flow/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-flow/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-flow/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-flow/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-flow.svg)](https://pypi.org/project/bluer-flow/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-flow)](https://pypistats.org/packages/bluer-flow)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 📜 [`bluer_flow-5.8.1`](https://github.com/kamangir/bluer-flow).
